
from mandaye.auth.saml2 import SAML2Auth
from mandaye.filters.replay import ReplayFilter
from mandaye.configs import saml2 as saml2_config

from cam.filters import archimed

base = 'EXPLOITATION'

form_values = {
        'login_url': '/%s/Default/accueil-ermes.aspx' % base,
        'post_url': '/%s/Default/Ermes/Recherche/logon.svc/logon' % base,
        'post_fields': ['username', 'password'],
        'username_field': 'username',
        'password_field': 'password',
        }

saml2_config.IDP_METADATA = "http://idp-montpellier.entrouvert.org/idp/saml2/metadata"

auth = SAML2Auth(form_values, 'archimed', saml2_config)

archimed_mapping = [
        {
            'path': r'/',
            'on_request': [{
                'filter': archimed.default_req,
                'decompress': False,
                }]
            },
        {
            'path': r'/',
            'content-types': ['text/html', 'application/javascript'],
            'on_response': [{
                'filter': archimed.default_resp,
                'decompress': False,
                }]
            },
        {
            'path': r'/%s/|/%s/' % (base, base.lower()),
            'method': 'GET',
            'content-types': ['text/html'],
            'on_response': [{
                'filter': archimed.rewrite_login_box,
                },
                {
                    'filter': archimed.rewrite_logged_box
                    },]
            },
        {
            'path': r'/mandaye/login$',
            'method': 'GET',
            'response': [{
                'filter': auth.login,
                'values': {
                    'associate_url': '/mandaye/associate',
                    },
                'condition': "'\"success\":true' in response.msg"
                },]
            },
        {
            'path': r'/mandaye/sso$',
            'method': 'GET',
            'response': [{
                'filter': auth.sso,
                }]
            },
        {
            'path': r'/mandaye/slo$',
            'method': 'GET',
            'response': [{
                'filter': auth.slo,
                }]
            },
        {
            'path': r'%s$' % auth.config.END_POINTS_PATH['metadata'],
            'method': 'GET',
            'response': [{
                'filter': auth.metadata,
                }]
            },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_sign_on_post'],
                'method': 'POST',
                'response': [{
                    'filter': auth.single_sign_on_post,
                    'values': {
                        'login_url': '/mandaye/login',
                        'next_url': '/%s/DEFAULT/accueil-ermes.aspx' % base
                        }
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout,
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout_return'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout_return,
                    'values': {
                        'next_url': '/%s/DEFAULT/accueil-ermes.aspx' % base
                        }
                    }]
                },
        {
                'path': r'/mandaye/associate$',
                'method': 'GET',
                'response': [{
                    'filter': archimed.associate,
                    'values': {
                        'action': '/mandaye/associate?next_url=/%s/DEFAULT/accueil-ermes.aspx' % base,
                        'template': 'archimed/associate.html',
                        'sp_name': 'Archimed',
                        'login_name': form_values['username_field'],
                        'password_name': form_values['password_field'],
                        },
                    }],
                'on_request': [{
                    'filter': archimed.associate_req,
                    'values': {
                        'action': '/mandaye/associate?next_url=/%s/DEFAULT/accueil-ermes.aspx' % base,
                        'login_name': form_values['username_field'],
                        'password_name': form_values['password_field'],
                    },
                    }]
                },
        {
                'path': r'/mandaye/associate_confirm$',
                'method': 'GET',
                'response': [{
                    'filter': archimed.associate_confirm,
                    'values': {
                        'associate_url': '/mandaye/associate',
                        'template': 'archimed/associate_confirm.html',
                        },
                    },]
                },
        {
                'path':  r'/mandaye/associate$',
                'method': 'POST',
                'response': [
                    {
                        'filter': auth.associate_submit,
                        'values': {
                            'connection_url': '/mandaye/sso',
                            'associate_url': '/mandaye/associate',
                            },
                        'condition': "'\"success\":true' in response.msg"
                        },
                    ],
                'on_reponse': [
                    {
                        'filter': archimed.clean_registration_session,
                        },
                    ],
                },
        {
                'path': r'/mandaye/json$',
                'method': 'GET',
                'response': [
                    {
                        'filter': archimed.json_response,
                        },
                    ]

                },
        ]


